package com.tanpu.fund.controller;

import com.tanpu.common.model.Page;
import com.tanpu.common.model.Pageable;
import com.tanpu.common.model.product.req.ProductListReq;
import com.tanpu.common.model.product.resp.*;
import com.tanpu.common.resp.CommonResp;
import com.tanpu.fund.api.ProductApi;
import com.tanpu.fund.api.model.req.NetReq;
import com.tanpu.fund.api.model.req.ProductInfoReq;
import com.tanpu.fund.api.model.resp.*;
import com.tanpu.fund.service.ProductService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Slf4j
public class ProductController implements ProductApi {

    @Resource
    private ProductService productService;

    @Override
    public CommonResp<Page<ProductInfoVO>> getProductInfo(ProductInfoReq req) {
        return CommonResp.success(this.productService.getProductList(req));
    }

    @Override
    public CommonResp<Page<ProductInfoVO>> getNotTanpuProductInfo(ProductInfoReq req) {
        return CommonResp.success(this.productService.getNotTanpuProduct(req));
    }

    @Override
    public CommonResp<ProductInfoVO> getProductDetailInfo(String id) {
        return CommonResp.success(this.productService.getProductDetail(id));
    }

    @Override
    public CommonResp<UnitNetVO> getUnitNetInfo(String id, String ratioId, String type) {
        return CommonResp.success(this.productService.getUnitNet(id, ratioId, type));
    }

    @Override
    public CommonResp<UnitNetVO> getProfitTrend(String id, String ratioId, String type, Long beginTime, Long endTime) {
        return CommonResp.success(this.productService.getProfitTrend(id, ratioId, type, beginTime, endTime));
    }

    @Override
    public CommonResp<Page<NetVO>> getNetListInfo(NetReq req) {
        return CommonResp.success(this.productService.getNetList(req));
    }

    @Override
    public CommonResp<List<TrackRecordVO>> getTrackRecordInfo(String id) {
        return CommonResp.success(this.productService.getTrackRecord(id));
    }

    @Override
    public CommonResp<Page<TrackNetVO>> getTrackNetListInfo(String id, Pageable page) {
        return CommonResp.success(this.productService.getTrackNetList(id, page));
    }

    @Override
    public CommonResp<List<RiskRatingVO>> getRiskRatingInfo(String id) {
        return CommonResp.success(this.productService.getRiskRating(id));
    }

    @Override
    public CommonResp<List<FundManagerVO>> getFundManagerInfo(String id) {
        return CommonResp.success(this.productService.getFundManager(id));
    }

    @Override
    public CommonResp<FundRecordVO> getFundRecordInfo(String id) {
        return CommonResp.success(this.productService.getFundRecord(id));
    }

    @Override
    public CommonResp<FundCompanyVO> getFundCompanyInfo(String id) {
        return CommonResp.success(this.productService.getFundCompany(id));
    }

    @Override
    public CommonResp<List<ProductInfoVO>> getProductInfolist(ProductListReq req) {
        List<ProductInfoVO> productInfolist = this.productService.getProductInfolist(req);
        return CommonResp.success(productInfolist);
    }

    @Override
    public CommonResp<List<ProductInfoVO>> getNotTanpuProductInfolist(ProductListReq req) {
        List<ProductInfoVO> notTanpuProductInfolist = this.productService.getNotTanpuProductInfolist(req);
        return CommonResp.success(notTanpuProductInfolist);
    }

    @Override
    public CommonResp<DynamicRetreatVO> getDynamicRetreatInfo(String id) {
        return CommonResp.success(this.productService.getDynamicRetreat(id));
    }
}
